;+
; NAME		disc_mask.pro
;
; PURPOSE	Set outer FOV pixels to zero.
;
; SYNTAX	disc_mask, img, icolor, xdim, ydim, xcen, ycen, pixrs,
;                          rmax=rmax
;
;		img		image array
;		icolor		color index (0-255) to set pixels in mask area.
;		xdim, ydim	image dimensions.
;		xcen, ycen	sun center.
;		pixrs		# pixels per solar radius.
;		rmax		outer FOV (Rsun units).
;
; EXAMPLES	img = disc_mask (img, icolor, xdim, ydim, xcen, yxcen, pixrs,$
;                                rmax=rmax)
;
; EXTERNAL
; PROCEDURES	none
;
; HISTORY	Andrew L. Stanger   Royal Observatory of Belgium   29 Jun 2007
;-

FUNCTION disc_mask, img, icolor, xdim, ydim, xcen, ycen, pixrs, rmax=rmax

   size_img = size (img)
   ixdim = size_img [1]
   iydim = size_img [2]

   if (ixdim GT xdim)  THEN $
   BEGIN
      print, 'X-axis image size: ', ixdim, ' GT xdim: ', xdim
   END 

   if (iydim GT ydim)  THEN $
   BEGIN
      print, 'Y-axis image size: ', iydim, ' GT xdim: ', ydim
   END 

   ; ---------------------------------------------------------------------------
   ; Default min and max radii.
   ; ---------------------------------------------------------------------------

   radmax = 2.80

   ; ---------------------------------------------------------------------------
   ; Compute distance from sun center to right edge of image..
   ; ---------------------------------------------------------------------------

   xdist = float (xdim-1) - xcen		; radial distance FOV (pixels).
   xmax  = xdist / pixrs			; radial distance FOV (Rsun).


   IF (NOT keyword_set (rmax))  THEN rmax = xmax

   ; ---------------------------------------------------------------------------
   ; Set pixels inside rmin and outside rmax to the color "icolor".
   ; ---------------------------------------------------------------------------

   FOR iy = 0, ydim - 1 DO $
   BEGIN
      y = float (iy) - ycen
      FOR ix = 0, xdim - 1 DO $
      BEGIN
;         print, 'ix, iy: ', ix, iy
	 x = float (ix) - xcen
	 d = sqrt (x*X + y*y)				; pixel units
	 r = d / pixrs			 		; solar radius units.
         IF (r GT rmax) THEN img [ix, iy] = icolor	; outer FOV limit.
      END
   END

RETURN, img
END
